@@ -84,9 +84,9 @@ validateUtils <- function(formula,
 	      stop("The 'metric' can not be 'BIC', 'CP', 'HQc', 'IC(1)', 'IC(3/2)', 'Rsq' or 'adjRsq' when using multivariate multiple regression!")
 	    }
 	  }
-		if(any(strategy == "subset") & any(metric == "SL")) {
-			stop("metric = 'SL' is not allowed when strategy = 'subset'")
-		}
+		# if(any(strategy == "subset") & any(metric == "SL")) {
+		# 	stop("metric = 'SL' is not allowed when strategy = 'subset'")
+		# }
 	  if(any(metric == "CP") & sigma_value == 0) {
 	    stop("metric = 'CP' is not allowed when Estimate of pure error variance from fitting the full model(sigma_value) is 0")
 	  }
